@@ -5,12 +5,12 @@
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * bijiben is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -36,8 +36,7 @@ typedef enum
   BJB_TOOLBAR_TRASH_LIST,
   BJB_TOOLBAR_TRASH_ICON,
   BJB_TOOLBAR_TRASH_SELECT,
-  BJB_TOOLBAR_NOTE_VIEW,
-  BJB_TOOLBAR_NUM
+  BJB_TOOLBAR_NOTE_VIEW
 } BjbToolbarType;
 
 /* Color Button */
@@ -151,7 +150,7 @@ update_selection_label (BjbMainToolbar *self)
   return TRUE;
 }
 
-void
+static void
 on_view_selection_changed_cb (BjbMainToolbar *self)
 {
   GtkStyleContext *context;
@@ -736,7 +735,7 @@ on_detached_clicked_cb (BjbMainToolbar *self)
 }
 
 
-GtkWidget *
+static GtkWidget *
 bjb_note_menu_new (BjbMainToolbar *self)
 {
   BjbMainToolbarPrivate *priv = self->priv;
@@ -768,7 +767,7 @@ bjb_note_menu_new (BjbMainToolbar *self)
   item = gtk_menu_item_new_with_label (_("Undo"));
   gtk_menu_shell_append (GTK_MENU_SHELL (result), item);
   g_signal_connect_swapped (item, "activate",
-                            G_CALLBACK (webkit_web_view_undo), editor);
+                            G_CALLBACK (biji_webkit_editor_undo), editor);
   gtk_widget_add_accelerator (item, "activate", priv->accel, GDK_KEY_z,
                              GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
@@ -776,7 +775,7 @@ bjb_note_menu_new (BjbMainToolbar *self)
   item = gtk_menu_item_new_with_label (_("Redo"));
   gtk_menu_shell_append (GTK_MENU_SHELL (result), item);
   g_signal_connect_swapped (item, "activate",
-                            G_CALLBACK (webkit_web_view_redo), editor);
+                            G_CALLBACK (biji_webkit_editor_redo), editor);
   gtk_widget_add_accelerator (item, "activate", priv->accel, GDK_KEY_z,
                              GDK_CONTROL_MASK | GDK_SHIFT_MASK, GTK_ACCEL_VISIBLE);
 
@@ -802,7 +801,7 @@ bjb_note_menu_new (BjbMainToolbar *self)
                     G_CALLBACK (on_email_note_callback), priv->note);
 
   g_signal_connect_swapped (biji_note_obj_get_editor (priv->note),
-                            "user-changed-contents",
+                            "content-changed",
                             G_CALLBACK (on_note_content_changed),
                             self);
 
@@ -958,6 +957,7 @@ populate_bar_switch (BjbMainToolbar *self)
       break;
 
     /* Spinner, Empty Results */
+    case BJB_TOOLBAR_0:
     default:
       gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (self), TRUE);
       break;
@@ -1015,8 +1015,11 @@ populate_main_toolbar(BjbMainToolbar *self)
 
     /* Not really a toolbar,
      * still used for Spinner */
+    case BJB_WINDOW_BASE_SPINNER_VIEW:
+    case BJB_WINDOW_BASE_ERROR_TRACKER:
+    case BJB_WINDOW_BASE_NO_VIEW:
     default:
-      to_be = BJB_TOOLBAR_0;
+      break;
   }
 
 
@@ -1069,8 +1072,10 @@ bjb_main_toolbar_constructed (GObject *obj)
 static void
 bjb_main_toolbar_init (BjbMainToolbar *self)
 {
+  BjbMainToolbarPrivate *priv;
+
   self->priv = BJB_MAIN_TOOLBAR_GET_PRIVATE(self);
-  BjbMainToolbarPrivate *priv = self->priv;
+  priv = self->priv;
 
   priv->type = BJB_TOOLBAR_0 ;
 
