@@ -63,20 +63,6 @@ struct _BjbWindowBasePriv
 /* Gobject */
 G_DEFINE_TYPE (BjbWindowBase, bjb_window_base, GTK_TYPE_APPLICATION_WINDOW);
 
-
-static GObject *
-bjb_window_base_constructor (GType                  gtype,
-                             guint                  n_properties,
-                             GObjectConstructParam  *properties)
-{
-  GObject *obj;
-  {
-    obj = G_OBJECT_CLASS (bjb_window_base_parent_class)->constructor (gtype, n_properties, properties);
-  }
-  return obj;
-}
-
-
 static void
 bjb_window_base_finalize (GObject *object)
 {
@@ -270,14 +256,20 @@ bjb_window_base_constructed (GObject *obj)
   const gint32 *size;
   gsize n_elements;
   GVariant *variant;
+  GdkVisual *rgba_visual;
 
   G_OBJECT_CLASS (bjb_window_base_parent_class)->constructed (obj);
 
   priv = self->priv;
   priv->settings = bjb_app_get_settings ((gpointer) g_application_get_default ());
 
-
-
+  /* Allow transparencies if possible */
+  rgba_visual = gdk_screen_get_rgba_visual (gtk_window_get_screen (GTK_WINDOW (self)));
+  if (rgba_visual)
+  {
+    gtk_widget_set_visual (GTK_WIDGET (self), rgba_visual);
+    gtk_widget_set_app_paintable (GTK_WIDGET (self), TRUE);
+  }
 
   gtk_window_set_position (GTK_WINDOW (self),GTK_WIN_POS_CENTER);
   gtk_window_set_title (GTK_WINDOW (self), _(BIJIBEN_MAIN_WIN_TITLE));
@@ -409,7 +401,6 @@ bjb_window_base_class_init (BjbWindowBaseClass *klass)
 
 
   gobject_class->constructed = bjb_window_base_constructed;
-  gobject_class->constructor = bjb_window_base_constructor;
   gobject_class->finalize = bjb_window_base_finalize ;
   gobject_class->get_property = bjb_window_base_get_property;
   gobject_class->set_property = bjb_window_base_set_property;
@@ -551,12 +542,13 @@ bjb_window_base_switch_to (BjbWindowBase *self, BjbWindowViewType type)
 
 
     case BJB_WINDOW_BASE_NOTE_VIEW:
-      gtk_widget_show_all (GTK_WIDGET (priv->note_view));
+      gtk_widget_show (GTK_WIDGET (priv->note_view));
       gtk_widget_hide (GTK_WIDGET (priv->search_bar));
       gtk_stack_set_visible_child_name (priv->stack, "note-view");
       break;
 
 
+    case BJB_WINDOW_BASE_NO_VIEW:
     default:
       return;
   }
