@@ -19,7 +19,7 @@
 
 /*
  * http://tools.ietf.org/html/rfc2445
- * 
+ *
  * Evolution UI offers to sync Memo to local computer
  * TODO: check this
  */
@@ -171,7 +171,7 @@ create_note_from_item (BijiMemoItem *item)
   biji_manager_get_default_color (manager, &color);
   biji_note_obj_set_rgba (note, &color);
   g_hash_table_replace (item->self->priv->items,
-                        item->set.url,
+                        g_strdup (item->set.url),
                         note);
 }
 
@@ -280,7 +280,7 @@ on_object_list_got (GObject      *obj,
       dtstart = time;
     else
       dtstart = 0;
-    // e_cal_component_free_datetime()
+    e_cal_component_free_datetime(&tz);
 
     e_cal_component_get_last_modified (co, &t); // or dtstart
     if (time_val_from_icaltime (t, &time))
@@ -323,7 +323,7 @@ on_object_list_got (GObject      *obj,
 
 
 
-static gchar *
+static const gchar *
 i_want_all_memos (void)
 {
   return "occur-in-time-range? (make-time \"19820421T204153Z\") (make-time \"20820423T232416Z\")";
@@ -362,6 +362,8 @@ on_notes_mined (GObject       *source_object,
                            g_strdup (tracker_sparql_cursor_get_string (cursor, 1, NULL)));
 
     }
+
+    g_object_unref (cursor);
   }
 
   e_cal_client_get_object_list (self->priv->client,
@@ -374,7 +376,7 @@ on_notes_mined (GObject       *source_object,
 
 
 /* From gnome-calendar -> ported to GdkRGBA */
-GdkPixbuf*
+static GdkPixbuf*
 get_pixbuf_from_color    (GdkRGBA              *color, gint size)
 {
   cairo_surface_t *surface;
@@ -440,8 +442,7 @@ on_client_connected (GObject      *obj,
                      GAsyncResult *res,
                      gpointer      user_data)
 {
-  GError *error;
-  error = NULL;
+  GError *error = NULL;
   gchar *query;
   BijiMemoProvider *self = BIJI_MEMO_PROVIDER (user_data);
 
@@ -531,9 +532,9 @@ on_object_created (GObject      *client,
 
 
 
-BijiNoteObj *
+static BijiNoteObj *
 memo_create_note (BijiProvider *provider,
-                  gchar        *str)
+                  const gchar  *str)
 {
   BijiMemoProvider *self = BIJI_MEMO_PROVIDER (provider);
   BijiInfoSet    info;
@@ -601,7 +602,7 @@ memo_create_note (BijiProvider *provider,
 
 
   /* make sure the component has an UID and info get it */
-  if (! (info.url = icalcomponent_get_uid (icalcomp)))
+  if (! (info.url = (gchar *) icalcomponent_get_uid (icalcomp)))
   {
     gchar *uid;
 
@@ -650,7 +651,8 @@ biji_memo_provider_init (BijiMemoProvider *self)
   priv = self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, BIJI_TYPE_MEMO_PROVIDER, BijiMemoProviderPrivate);
 
   priv->queue = g_queue_new ();
-  priv->items = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+  priv->items = g_hash_table_new_full (g_str_hash, g_str_equal,
+                                       g_free, g_object_unref);
   priv->tracker = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
   priv->memos = NULL;
 
@@ -659,7 +661,13 @@ biji_memo_provider_init (BijiMemoProvider *self)
 static void
 biji_memo_provider_finalize (GObject *object)
 {
-  e_cal_client_free_icalcomp_slist (BIJI_MEMO_PROVIDER (object)->priv->memos);
+  BijiMemoProviderPrivate *priv = BIJI_MEMO_PROVIDER (object)->priv;
+
+  e_cal_client_free_icalcomp_slist (priv->memos);
+
+  g_hash_table_unref (priv->tracker);
+  g_hash_table_unref (priv->items);
+  g_queue_free_full (priv->queue, (GDestroyNotify) memo_item_free);
 
   G_OBJECT_CLASS (biji_memo_provider_parent_class)->finalize (object);
 }
@@ -708,7 +716,7 @@ biji_memo_provider_get_property (GObject    *object,
 
 
 
-const BijiProviderInfo *
+static const BijiProviderInfo *
 memo_provider_get_info (BijiProvider *provider)
 {
   return &(BIJI_MEMO_PROVIDER (provider)->priv->info);
